# Getting Started

In order to use Windows Git, you will need a Glulx game file to play on it. This format was invented by Andrew Plotkin to address the limitations of the widely used Z-code format (also referred to as the Z-Machine), which was originally invented by Infocom, Inc. for the games they released during the 1980s.

Members of the current interactive fiction community have written many games using Graham Nelson's compiler Inform. Inform can produce as output either Z-code or Glulx game files. Glulx games can be downloaded from the IF Archive at
http://www.ifarchive.org/indexes/if-archiveXgamesXglulx.html

When Windows Git is first started, a file dialog opens, prompting you for a game file to load. This file can be either a Glulx file or a Blorb file. A Glulx file has a name ending with .ulx. A Blorb file contains multimedia resources for games, and can also contain the Glulx game as well. Blorb files have a name ending with .blb, .blorb, .glb or .gblorb.

Once a game file is selected, Windows Git will open its main window and start running the game. If the game is packaged with an iFiction record, then the cover art and description is shown first.

Further information:

- Menus and the toolbar
- Editing keys
- Changing options